summaryrefslogtreecommitdiffstats
path: root/src/devices/pic/base/pic_config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/pic/base/pic_config.h')
-rw-r--r--src/devices/pic/base/pic_config.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/devices/pic/base/pic_config.h b/src/devices/pic/base/pic_config.h
index 67c0b1c..6e13210 100644
--- a/src/devices/pic/base/pic_config.h
+++ b/src/devices/pic/base/pic_config.h
@@ -48,9 +48,9 @@ public:
public:
TQString name;
TQStringList ignoredCNames;
- BitValue wtqmask, ptqmask, ctqmask; // write, protected, and checksum bits tqmasks
+ BitValue wtqmask, ptqmask, ctqmask; // write, protected, and checksum bits masks
BitValue bvalue; // blank value
- TQValueVector<Mask> tqmasks; // ordered from lower to higher
+ TQValueVector<Mask> masks; // ordered from lower to higher
BitValue usedMask() const;
};
@@ -62,7 +62,7 @@ public:
const Value *findValue(const TQString &tqmask, const TQString &value) const;
const Mask *findMask(const TQString &tqmask, uint *wordIndex = 0) const;
static bool hasMaskName(const TQString &tqmask);
- static TQString tqmaskLabel(const TQString &tqmask);
+ static TQString maskLabel(const TQString &tqmask);
bool checkValueName(const TQString &tqmask, const TQString &name) const;
static TQString valueLabel(const TQString &tqmask, const TQString &name);
@@ -73,8 +73,8 @@ private:
MapData(int i, int b) : index(i), block(b) {}
int index, block;
};
- static TQMap<TQString, MapData> &tqmasks();
- static TQMap<TQString, MapData> *_tqmasks; // tqmask name -> index in DATA
+ static TQMap<TQString, MapData> &masks();
+ static TQMap<TQString, MapData> *_masks; // tqmask name -> index in DATA
struct NameData {
const char *name, *label;